.. Python-Misfit

Python-Misfit: It's an API client
=================================

.. include:: ../misfit/__init__.py
   :start-after: """
   :end-before: """

Contents:

.. toctree::
   :maxdepth: 3

   installing
   getting_started
   notifications
   misfit
   history


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
